==> countries-db-1.0.0.tgz: package/test/unit/get-country/fixtures.js <==
module.exports = {
  AQ: {
    id: 'AQ',
    name: 'Antarctica',
    officialName: 'All land and ice shelves south of the 60th parallel south',
    emoji: '🇦🇶',
    emojiUnicode: 'U+1F1E6 U+1F1F6',
    iso2: 'AQ',
    iso3: 'ATA',
    isoNumeric: '010',
    geonameId: 6697173,
    continentId: 'AN',
    population: 1106,
    elevation: 2500,
    areaSqKm: 14200000,
    coordinates: {
      latitude: -82.8628,
      longitude: -135
    },
    timezones: [
      'Antarctica/Casey',
      'Antarctica/Davis',
      'Antarctica/DumontDUrville',
      'Antarctica/Mawson',
      'Antarctica/McMurdo',
      'Antarctica/Palmer',
      'Antarctica/Rothera',
      'Antarctica/Syowa',
      'Antarctica/Troll',
      'Antarctica/Vostok'
    ],
    domain: '.aq',
    currencyCode: null,
    currencyName: null,
    postalCodeFormat: null,
    postalCodeRegex: null,
    phoneCode: null,
    neighbourCountryIds: [],
    languages: [],
    locales: []
  },
  MX: {
    id: 'MX',
    name: 'Mexico',
    officialName: 'The United Mexican States',
    emoji: '🇲🇽',
    emojiUnicode: 'U+1F1F2 U+1F1FD',
    iso2: 'MX',
    iso3: 'MEX',
    isoNumeric: '484',
    geonameId: 3996063,
    continentId: 'NA',
    population: 112468855,
    elevation: 2062,
    areaSqKm: 1972550,
    coordinates: {
      latitude: 23,
      longitude: -102
    },
    timezones: [
      'America/Bahia_Banderas',
      'America/Cancun',
      'America/Chihuahua',
      'America/Ensenada',
      'America/Hermosillo',
      'America/Matamoros',
      'America/Mazatlan',
      'America/Merida',
      'America/Mexico_City',
      'America/Monterrey',
      'America/Ojinaga',
      'America/Santa_Isabel',
      'America/Tijuana'
    ],
    domain: '.mx',
    currencyCode: 'MXN',
    currencyName: 'Peso',
    postalCodeFormat: '#####',
    postalCodeRegex: '^(\\d{5})$',
    phoneCode: '+52',
    neighbourCountryIds: [ 'GT', 'US', 'BZ' ],
    languages: [ 'es' ],
    locales: [ 'es-MX' ]
  },
  SH: {
    id: 'SH',
    name: 'Saint Helena, Ascension and Tristan da Cunha',
    officialName: 'Saint Helena, Ascension and Tristan da Cunha',
    emoji: '🇸🇭',
    emojiUnicode: 'U+1F1F8 U+1F1ED',
    iso2: 'SH',
    iso3: 'SHN',
    isoNumeric: '654',
    geonameId: 3370751,
    continentId: 'AF',
    population: 7460,
    elevation: 572,
    areaSqKm: 410,
    coordinates: {
      latitude: -15.95,
      longitude: -5.7
    },
    timezones: [ 'Atlantic/St_Helena' ],
    domain: '.sh',
    currencyCode: 'SHP',
    currencyName: 'Pound',
    postalCodeFormat: 'STHL 1ZZ',
    postalCodeRegex: '^(STHL1ZZ)$',
    phoneCode: '+290',
    neighbourCountryIds: [],
    languages: [ 'en' ],
    locales: [ 'en-SH' ]
  }
};

==> countries-db-1.1.0.tgz: package/test/unit/get-country/fixtures.js <==
module.exports = {
  AQ: {
    id: 'AQ',
    name: 'Antarctica',
    officialName: 'All land and ice shelves south of the 60th parallel south',
    emoji: '🇦🇶',
    emojiUnicode: 'U+1F1E6 U+1F1F6',
    iso2: 'AQ',
    iso3: 'ATA',
    isoNumeric: '010',
    geonameId: 6697173,
    continentId: 'AN',
    population: 1106,
    elevation: 2500,
    areaSqKm: 14200000,
    coordinates: {
      latitude: -82.8628,
      longitude: -135
    },
    timezones: [
      'Antarctica/Casey',
      'Antarctica/Davis',
      'Antarctica/DumontDUrville',
      'Antarctica/Mawson',
      'Antarctica/McMurdo',
      'Antarctica/Palmer',
      'Antarctica/Rothera',
      'Antarctica/Syowa',
      'Antarctica/Troll',
      'Antarctica/Vostok'
    ],
    domain: '.aq',
    currencyCode: null,
    currencyName: null,
    postalCodeFormat: null,
    postalCodeRegex: null,
    phoneCode: null,
    neighborCountryIds: [],
    languages: [],
    locales: []
  },
  MX: {
    id: 'MX',
    name: 'Mexico',
    officialName: 'The United Mexican States',
    emoji: '🇲🇽',
    emojiUnicode: 'U+1F1F2 U+1F1FD',
    iso2: 'MX',
    iso3: 'MEX',
    isoNumeric: '484',
    geonameId: 3996063,
    continentId: 'NA',
    population: 112468855,
    elevation: 2062,
    areaSqKm: 1972550,
    coordinates: {
      latitude: 23,
      longitude: -102
    },
    timezones: [
      'America/Bahia_Banderas',
      'America/Cancun',
      'America/Chihuahua',
      'America/Ensenada',
      'America/Hermosillo',
      'America/Matamoros',
      'America/Mazatlan',
      'America/Merida',
      'America/Mexico_City',
      'America/Monterrey',
      'America/Ojinaga',
      'America/Santa_Isabel',
      'America/Tijuana'
    ],
    domain: '.mx',
    currencyCode: 'MXN',
    currencyName: 'Peso',
    postalCodeFormat: '#####',
    postalCodeRegex: '^(\\d{5})$',
    phoneCode: '+52',
    neighborCountryIds: [ 'GT', 'US', 'BZ' ],
    languages: [ 'es' ],
    locales: [ 'es-MX' ]
  },
  SH: {
    id: 'SH',
    name: 'Saint Helena, Ascension and Tristan da Cunha',
    officialName: 'Saint Helena, Ascension and Tristan da Cunha',
    emoji: '🇸🇭',
    emojiUnicode: 'U+1F1F8 U+1F1ED',
    iso2: 'SH',
    iso3: 'SHN',
    isoNumeric: '654',
    geonameId: 3370751,
    continentId: 'AF',
    population: 7460,
    elevation: 572,
    areaSqKm: 410,
    coordinates: {
      latitude: -15.95,
      longitude: -5.7
    },
    timezones: [ 'Atlantic/St_Helena' ],
    domain: '.sh',
    currencyCode: 'SHP',
    currencyName: 'Pound',
    postalCodeFormat: 'STHL 1ZZ',
    postalCodeRegex: '^(STHL1ZZ)$',
    phoneCode: '+290',
    neighborCountryIds: [],
    languages: [ 'en' ],
    locales: [ 'en-SH' ]
  }
};
